@@ -4,10 +4,7 @@
 // #![warn(clippy::pedantic)]
 //! # postgres-es
 //!
-//! > Common persistence logic used for database-backed event stores for cqrs-es.
-//!
-//! [![Crates.io](https://img.shields.io/crates/v/persist-es)](https://crates.io/crates/persist-es)
-//! [![docs](https://img.shields.io/badge/API-docs-blue.svg)](https://docs.rs/persist-es)
+//! > Common persistence logic used for database-backed event stores for [cqrs-es](https://crates.io/crates/persist-es).
 //!
 mod context;
 mod error;
@@ -20,5 +17,5 @@ pub use context::{EventStoreAggregateContext, QueryContext, SnapshotStoreAggrega
 pub use error::PersistenceError;
 pub use event_store::PersistedEventStore;
 pub use queries::GenericQuery;
-pub use repository::{PersistedEventRepository, PersistedSnapshotEventRepository, ViewRepository};
+pub use repository::{PersistedEventRepository, ViewRepository};
 pub use snapshot_store::PersistedSnapshotStore;
